@@ -1,7 +1,8 @@
 #!/usr/bin/python3
+import datetime
 import json
 import os
-import datetime
+
 import pyrebase
 
 
@@ -29,18 +30,20 @@ class Authentication(object):
         "apiKey": "AIzaSyDKAuaWu9qPNHU0Y9gACRDv3Esj6T8w3kE",
         "authDomain": "canarid-621aa.firebaseapp.com",
         "databaseURL": "https://canarid-621aa.firebaseio.com",
-        "storageBucket": ""
+        "storageBucket": "",
     }
 
     def printifv(self, msg):
         if self._verbose:
             print(f"[Authentication] {msg}")
 
-    def __init__(self,
-                 generate_new: bool = False,
-                 verbose: bool = False,
-                 auth_path: str = kAuthPath,
-                 skip_refresh_on_init=False):
+    def __init__(
+        self,
+        generate_new: bool = False,
+        verbose: bool = False,
+        auth_path: str = kAuthPath,
+        skip_refresh_on_init=False,
+    ):
         """
         Constructor
         :param generate_new: Will prompt the user to create a new third-party token rather than refreshing an existing one.
@@ -83,10 +86,15 @@ class Authentication(object):
         # Try to load up the file
         #
         try:
-            self._id_token, self._refresh_token, self.maybe_id_token_expire_time = self._load_file()
+            (
+                self._id_token,
+                self._refresh_token,
+                self.maybe_id_token_expire_time,
+            ) = self._load_file()
         except FailedLoadingAuthFileException as e:
             raise FailedLoadingAuthFileException(
-                f"Failed to read authentication file. Please run the authentication refresh with 'generate' option generate a new third-party token and authentication file. ({str(e)})")
+                f"Failed to read authentication file. Please run the authentication refresh with 'generate' option generate a new third-party token and authentication file. ({str(e)})"
+            )
 
         #
         # If it looks like the timer for expiration has passed or is close, ask for a refresh
@@ -95,13 +103,16 @@ class Authentication(object):
             self.printifv("Refreshing token...")
             refresh_result = self._firebase.auth().refresh(self._refresh_token)
             self.printifv("Updating locally stored credentials...")
-            self._write_file(refresh_result["idToken"],
-                             refresh_result["refreshToken"],
-                             unix_time_now_seconds())
+            self._write_file(
+                refresh_result["idToken"],
+                refresh_result["refreshToken"],
+                unix_time_now_seconds(),
+            )
             return True
         else:
             self.printifv(
-                "Looks like the token has been refreshed recently enough. not refreshing")
+                "Looks like the token has been refreshed recently enough. not refreshing"
+            )
             return False
 
     def get_secret_token_id(self):
@@ -112,10 +123,13 @@ class Authentication(object):
     # ##############################################################################
     def _generate_new(self):
         custom_token = input(
-            "Please use https://REDACTED to generate a new token. Paste it here: ")
+            "Please use https://REDACTED to generate a new token. Paste it here: "
+        )
 
         self.printifv("Retreiving updated credentials...")
-        custom_token_result = self._firebase.auth().sign_in_with_custom_token(custom_token)
+        custom_token_result = self._firebase.auth().sign_in_with_custom_token(
+            custom_token
+        )
 
         id_token = custom_token_result["idToken"]
         refresh_token = custom_token_result["refreshToken"]
@@ -128,13 +142,19 @@ class Authentication(object):
         """
         This creates or overwrites
         """
-        with open(self._auth_path, 'w') as auth_file:
-            auth_file.seek(0)
-            json.dump({"id_token": id_token,
-                       "refresh_token": refresh_token,
-                       "maybe_id_token_expire_time": maybe_id_token_expire_time},
-                      auth_file)
-            auth_file.truncate()
+        try:
+            os.remove(self._auth_path)
+        except:
+            pass
+        with open(self._auth_path, "w") as auth_file:
+            json.dump(
+                {
+                    "id_token": id_token,
+                    "refresh_token": refresh_token,
+                    "maybe_id_token_expire_time": maybe_id_token_expire_time,
+                },
+                auth_file,
+            )
 
     def _load_file(self):
         """
@@ -144,11 +164,11 @@ class Authentication(object):
         """
         if not os.path.exists(self._auth_path):
             raise FailedLoadingAuthFileException(
-                f"File does not exist: {self._auth_path}")
+                f"File does not exist: {self._auth_path}"
+            )
 
         with open(self._auth_path) as auth_file:
-            id_token, refresh_token, maybe_id_token_expire_time = (
-                None, None, None)
+            id_token, refresh_token, maybe_id_token_expire_time = (None, None, None)
             try:
                 keys = json.load(auth_file)
                 id_token = keys["id_token"]
@@ -156,6 +176,7 @@ class Authentication(object):
                 maybe_id_token_expire_time = keys["maybe_id_token_expire_time"]
             except:
                 raise FailedLoadingAuthFileException(
-                    f"Corrupt: could not read required keys: {auth_path}")
+                    f"Corrupt: could not read required keys: {self._auth_path}"
+                )
 
         return id_token, refresh_token, maybe_id_token_expire_time
